@@ -1,4 +1,5 @@
 from abc import ABC
+from types import ModuleType
 from typing import Optional, List
 from importlib import import_module
 
@@ -46,10 +47,10 @@ def get_datafeed() -> BaseDatafeed:
 
     # Try to import datafeed module
     try:
-        module = import_module(module_name)
+        module: ModuleType = import_module(module_name)
     except ModuleNotFoundError:
         print(f"找不到数据服务驱动{module_name}，使用默认的RQData数据服务")
-        module = import_module("vnpy_rqdata")
+        module: ModuleType = import_module("vnpy_rqdata")
 
     # Create datafeed object from module
     datafeed = module.Datafeed()
