@@ -1,11 +1,9 @@
-"""
-"""
-
 import logging
 from logging import Logger
 import smtplib
 import os
 from abc import ABC
+from pathlib import Path
 from datetime import datetime
 from email.message import EmailMessage
 from queue import Empty, Queue
@@ -51,7 +49,7 @@ class MainEngine:
     Acts as the core of the trading platform.
     """
 
-    def __init__(self, event_engine: EventEngine = None):
+    def __init__(self, event_engine: EventEngine = None) -> None:
         """"""
         if event_engine:
             self.event_engine: EventEngine = event_engine
@@ -71,7 +69,7 @@ class MainEngine:
         """
         Add function engine.
         """
-        engine = engine_class(self, self.event_engine)
+        engine: BaseEngine = engine_class(self, self.event_engine)
         self.engines[engine.engine_name] = engine
         return engine
 
@@ -81,9 +79,9 @@ class MainEngine:
         """
         # Use default name if gateway_name not passed
         if not gateway_name:
-            gateway_name = gateway_class.default_name
+            gateway_name: str = gateway_class.default_name
 
-        gateway = gateway_class(self.event_engine, gateway_name)
+        gateway: BaseGateway = gateway_class(self.event_engine, gateway_name)
         self.gateways[gateway_name] = gateway
 
         # Add gateway supported exchanges into engine
@@ -97,10 +95,10 @@ class MainEngine:
         """
         Add app.
         """
-        app = app_class()
+        app: BaseApp = app_class()
         self.apps[app.app_name] = app
 
-        engine = self.add_engine(app.engine_class)
+        engine: BaseEngine = self.add_engine(app.engine_class)
         return engine
 
     def init_engines(self) -> None:
@@ -115,15 +113,15 @@ class MainEngine:
         """
         Put log event with specific message.
         """
-        log = LogData(msg=msg, gateway_name=source)
-        event = Event(EVENT_LOG, log)
+        log: LogData = LogData(msg=msg, gateway_name=source)
+        event: Event = Event(EVENT_LOG, log)
         self.event_engine.put(event)
 
     def get_gateway(self, gateway_name: str) -> BaseGateway:
         """
         Return gateway object by name.
         """
-        gateway = self.gateways.get(gateway_name, None)
+        gateway: BaseGateway = self.gateways.get(gateway_name, None)
         if not gateway:
             self.write_log(f"找不到底层接口：{gateway_name}")
         return gateway
@@ -132,7 +130,7 @@ class MainEngine:
         """
         Return engine object by name.
         """
-        engine = self.engines.get(engine_name, None)
+        engine: BaseEngine = self.engines.get(engine_name, None)
         if not engine:
             self.write_log(f"找不到引擎：{engine_name}")
         return engine
@@ -141,7 +139,7 @@ class MainEngine:
         """
         Get default setting dict of a specific gateway.
         """
-        gateway = self.get_gateway(gateway_name)
+        gateway: BaseGateway = self.get_gateway(gateway_name)
         if gateway:
             return gateway.get_default_setting()
         return None
@@ -168,7 +166,7 @@ class MainEngine:
         """
         Start connection of a specific gateway.
         """
-        gateway = self.get_gateway(gateway_name)
+        gateway: BaseGateway = self.get_gateway(gateway_name)
         if gateway:
             gateway.connect(setting)
 
@@ -176,7 +174,7 @@ class MainEngine:
         """
         Subscribe tick data update of a specific gateway.
         """
-        gateway = self.get_gateway(gateway_name)
+        gateway: BaseGateway = self.get_gateway(gateway_name)
         if gateway:
             gateway.subscribe(req)
 
@@ -184,7 +182,7 @@ class MainEngine:
         """
         Send new order request to a specific gateway.
         """
-        gateway = self.get_gateway(gateway_name)
+        gateway: BaseGateway = self.get_gateway(gateway_name)
         if gateway:
             return gateway.send_order(req)
         else:
@@ -194,7 +192,7 @@ class MainEngine:
         """
         Send cancel order request to a specific gateway.
         """
-        gateway = self.get_gateway(gateway_name)
+        gateway: BaseGateway = self.get_gateway(gateway_name)
         if gateway:
             gateway.cancel_order(req)
 
@@ -202,7 +200,7 @@ class MainEngine:
         """
         Send new quote request to a specific gateway.
         """
-        gateway = self.get_gateway(gateway_name)
+        gateway: BaseGateway = self.get_gateway(gateway_name)
         if gateway:
             return gateway.send_quote(req)
         else:
@@ -212,7 +210,7 @@ class MainEngine:
         """
         Send cancel quote request to a specific gateway.
         """
-        gateway = self.get_gateway(gateway_name)
+        gateway: BaseGateway = self.get_gateway(gateway_name)
         if gateway:
             gateway.cancel_quote(req)
 
@@ -220,7 +218,7 @@ class MainEngine:
         """
         Query bar history data from a specific gateway.
         """
-        gateway = self.get_gateway(gateway_name)
+        gateway: BaseGateway = self.get_gateway(gateway_name)
         if gateway:
             return gateway.query_history(req)
         else:
@@ -251,13 +249,13 @@ class BaseEngine(ABC):
         main_engine: MainEngine,
         event_engine: EventEngine,
         engine_name: str,
-    ):
+    ) -> None:
         """"""
-        self.main_engine = main_engine
-        self.event_engine = event_engine
-        self.engine_name = engine_name
+        self.main_engine: MainEngine = main_engine
+        self.event_engine: EventEngine = event_engine
+        self.engine_name: str = engine_name
 
-    def close(self):
+    def close(self) -> None:
         """"""
         pass
 
@@ -267,7 +265,7 @@ class LogEngine(BaseEngine):
     Processes log event and output with logging module.
     """
 
-    def __init__(self, main_engine: MainEngine, event_engine: EventEngine):
+    def __init__(self, main_engine: MainEngine, event_engine: EventEngine) -> None:
         """"""
         super(LogEngine, self).__init__(main_engine, event_engine, "log")
 
@@ -279,7 +277,7 @@ class LogEngine(BaseEngine):
         self.logger: Logger = logging.getLogger("veighna")
         self.logger.setLevel(self.level)
 
-        self.formatter = logging.Formatter(
+        self.formatter: logging.Formatter = logging.Formatter(
             "%(asctime)s  %(levelname)s: %(message)s"
         )
 
@@ -297,14 +295,14 @@ class LogEngine(BaseEngine):
         """
         Add null handler for logger.
         """
-        null_handler = logging.NullHandler()
+        null_handler: logging.NullHandler = logging.NullHandler()
         self.logger.addHandler(null_handler)
 
     def add_console_handler(self) -> None:
         """
         Add console output of log.
         """
-        console_handler = logging.StreamHandler()
+        console_handler: logging.StreamHandler = logging.StreamHandler()
         console_handler.setLevel(self.level)
         console_handler.setFormatter(self.formatter)
         self.logger.addHandler(console_handler)
@@ -313,12 +311,12 @@ class LogEngine(BaseEngine):
         """
         Add file output of log.
         """
-        today_date = datetime.now().strftime("%Y%m%d")
-        filename = f"vt_{today_date}.log"
-        log_path = get_folder_path("log")
-        file_path = log_path.joinpath(filename)
+        today_date: str = datetime.now().strftime("%Y%m%d")
+        filename: str = f"vt_{today_date}.log"
+        log_path: Path = get_folder_path("log")
+        file_path: Path = log_path.joinpath(filename)
 
-        file_handler = logging.FileHandler(
+        file_handler: logging.FileHandler = logging.FileHandler(
             file_path, mode="a", encoding="utf8"
         )
         file_handler.setLevel(self.level)
@@ -333,7 +331,7 @@ class LogEngine(BaseEngine):
         """
         Process log event.
         """
-        log = event.data
+        log: LogData = event.data
         self.logger.log(log.level, log.msg)
 
 
@@ -342,7 +340,7 @@ class OmsEngine(BaseEngine):
     Provides order management system function.
     """
 
-    def __init__(self, main_engine: MainEngine, event_engine: EventEngine):
+    def __init__(self, main_engine: MainEngine, event_engine: EventEngine) -> None:
         """"""
         super(OmsEngine, self).__init__(main_engine, event_engine, "oms")
 
@@ -532,7 +530,7 @@ class OmsEngine(BaseEngine):
         if not vt_symbol:
             return list(self.active_orders.values())
         else:
-            active_orders = [
+            active_orders: List[OrderData] = [
                 order
                 for order in self.active_orders.values()
                 if order.vt_symbol == vt_symbol
@@ -542,13 +540,12 @@ class OmsEngine(BaseEngine):
     def get_all_active_quotes(self, vt_symbol: str = "") -> List[QuoteData]:
         """
         Get all active quotes by vt_symbol.
-
         If vt_symbol is empty, return all active qutoes.
         """
         if not vt_symbol:
             return list(self.active_quotes.values())
         else:
-            active_quotes = [
+            active_quotes: List[QuoteData] = [
                 quote
                 for quote in self.active_quotes.values()
                 if quote.vt_symbol == vt_symbol
@@ -561,7 +558,7 @@ class EmailEngine(BaseEngine):
     Provides email sending function.
     """
 
-    def __init__(self, main_engine: MainEngine, event_engine: EventEngine):
+    def __init__(self, main_engine: MainEngine, event_engine: EventEngine) -> None:
         """"""
         super(EmailEngine, self).__init__(main_engine, event_engine, "email")
 
@@ -579,9 +576,9 @@ class EmailEngine(BaseEngine):
 
         # Use default receiver if not specified.
         if not receiver:
-            receiver = SETTINGS["email.receiver"]
+            receiver: str = SETTINGS["email.receiver"]
 
-        msg = EmailMessage()
+        msg: EmailMessage = EmailMessage()
         msg["From"] = SETTINGS["email.sender"]
         msg["To"] = receiver
         msg["Subject"] = subject
@@ -593,7 +590,7 @@ class EmailEngine(BaseEngine):
         """"""
         while self.active:
             try:
-                msg = self.queue.get(block=True, timeout=1)
+                msg: EmailMessage = self.queue.get(block=True, timeout=1)
 
                 with smtplib.SMTP_SSL(
                     SETTINGS["email.server"], SETTINGS["email.port"]
